@@ -1,18 +1,19 @@
 import logging
 import os
 
-from django.conf import settings
-from office365.runtime.auth.authentication_context import AuthenticationContext
+from office365.runtime.auth.userCredential import UserCredential
+from office365.sharepoint.caml.camlquery_builder import CamlQueryBuilder
+from office365.sharepoint.caml.querystring_builder import QueryStringBuilder
 from office365.sharepoint.client_context import ClientContext
-from office365.sharepoint.file_creation_information import FileCreationInformation
-from office365.sharepoint.helpers.querystring_builder import QueryStringBuilder
+from office365.sharepoint.files.file import File
+from office365.sharepoint.files.file_creation_information import FileCreationInformation
 
-from unicef_sharepoint.lib import File, ICamlQueryBuilder
+from unicef_sharepoint import config
 
 logger = logging.getLogger(__name__)
 
 
-default_select = '*,FileLeafRef'
+default_select = ['*', 'FileLeafRef']
 
 
 class SharePointClientException(BaseException):
@@ -23,21 +24,16 @@ class SharePointClient:
     """Client to access SharePoint Document Library"""
 
     def __init__(self, *args, **kwargs) -> None:
-        self.site_path = kwargs.get('url', settings.SHAREPOINT_TENANT['url'])
         self.relative_url = kwargs.get('relative_url', None)
-        username = kwargs.get('username', settings.SHAREPOINT_TENANT['user_credentials']['username'])
-        password = kwargs.get('password', settings.SHAREPOINT_TENANT['user_credentials']['password'])
+        self.site_path = kwargs.get('url', config.SHAREPOINT_TENANT)
+        username = kwargs.get('username', config.SHAREPOINT_USERNAME)
+        password = kwargs.get('password', config.SHAREPOINT_PASSWORD)
         self.folder = kwargs.get('folder', 'Documents')
-        ctx_auth = AuthenticationContext(url=self.site_path)
-        if ctx_auth.acquire_token_for_user(username=username, password=password):
-            self.context = ClientContext(self.site_path, ctx_auth)
-        else:
-            logger.exception(ctx_auth.get_last_error())
-            raise SharePointClientException(ctx_auth.get_last_error())
+        self.context = ClientContext.connect_with_credentials(self.site_path, UserCredential(username, password))
 
     def get_folder(self, list_title):
         list_obj = self.context.web.lists.get_by_title(list_title)
-        folder = list_obj.root_folder
+        folder = list_obj.rootFolder
         self.context.load(folder)
         self.context.execute_query()
         logger.info(f'List url: {folder.properties["ServerRelativeUrl"]}')
@@ -86,7 +82,7 @@ class SharePointClient:
     def read_caml_items(self, filters=None, scope=None):
         filters = filters or dict()
         list_obj = self.context.web.lists.get_by_title(self.folder)
-        qry = ICamlQueryBuilder(filters, scope).get_query()
+        qry = CamlQueryBuilder(filters, scope).get_query()
         items = list_obj.get_items(qry)
         self.context.execute_query()
         return items
@@ -106,7 +102,7 @@ class SharePointClient:
             file_content = content_file.read()
 
         if upload_into_library:
-            target_folder = self.context.web.lists.get_by_title(list_title).root_folder
+            target_folder = self.context.web.lists.get_by_title(list_title).rootFolder
             file = self.upload_file_alt(target_folder, os.path.basename(path), file_content)
             logger.info('File url: {}'.format(file.properties['ServerRelativeUrl']))
         else:
