@@ -1,5 +1,5 @@
 from django.conf import settings
-from office365.sharepoint.helpers.utils import to_camel
+from office365.sharepoint.caml.utils import to_camel
 from rest_framework import serializers
 from rest_framework.reverse import reverse
 
@@ -55,7 +55,7 @@ class SharePointLibrarySerializer(serializers.ModelSerializer):
     api_url = serializers.SerializerMethodField()
 
     def get_api_url(self, obj):
-        reverse_url = reverse('unicef_sharepoint:sharepoint-list',
+        reverse_url = reverse('unicef_sharepoint:sharepoint-rest-list',
                               kwargs={'tenant': obj.site.tenant.name, 'site': obj.site.name, 'folder': obj.name})
         return settings.HOST + reverse_url
 
@@ -64,7 +64,7 @@ class SharePointLibrarySerializer(serializers.ModelSerializer):
         fields = ('name', 'site_name', 'active', 'library_url', 'api_url')
 
 
-class SharePointItemSerializer(serializers.Serializer):
+class BaseSharePointItemSerializer(serializers.Serializer):
 
     id = UpperSharePointPropertyField()
     guid = UpperSharePointPropertyField()
@@ -77,6 +77,24 @@ class SharePointItemSerializer(serializers.Serializer):
     file_leaf_ref = SharePointPropertyField()
     file_ref = SharePointPropertyField()
 
+
+class SimpleSharePointItemSerializer(BaseSharePointItemSerializer):
+    def get_download_url(self, obj):
+        filename = obj.properties.get('FileLeafRef', obj.properties.get('Title', ''))
+        if filename:
+            k = filename.rfind(".")
+            if k > 0:
+                filename = filename[:k] + "." + filename[k + 1:]
+            else:
+                filename = f'{filename}.pdf'
+        relative_url = reverse('unicef_sharepoint:simple-sharepoint-files-download', kwargs={
+            'folder': self.context['folder'],
+            'filename': filename
+        })
+        return f'{settings.HOST}{relative_url}'
+
+
+class SharePointItemSerializer(BaseSharePointItemSerializer):
     def get_download_url(self, obj):
         filename = obj.properties.get('FileLeafRef', obj.properties.get('Title', ''))
         if filename:
