@@ -4,7 +4,10 @@ from unicef_sharepoint.views import (
     FileSharePointViewSet,
     ItemSharePointCamlViewSet,
     ItemSharePointViewSet,
+    SharePointCamlViewSet,
+    SharePointFileViewSet,
     SharePointLibraryViewSet,
+    SharePointRestViewSet,
     SharePointSiteViewSet,
     SharePointTenantViewSet,
 )
@@ -19,8 +22,11 @@ router.register(r'libraries', SharePointLibraryViewSet, basename='sharepoint-lib
 router.register(r'sharepoint/(?P<tenant>[\w\-]+)/(?P<site>[\w\-]+)/(?P<folder>[\w\W]+)/files',
                 FileSharePointViewSet, basename='sharepoint-files')
 router.register(r'sharepoint/(?P<tenant>[\w\-]+)/(?P<site>[\w\-]+)/(?P<folder>[\w\W]+)/rest',
-                ItemSharePointViewSet, basename='sharepoint')
+                ItemSharePointViewSet, basename='sharepoint-rest')
 router.register(r'sharepoint/(?P<tenant>[\w\-]+)/(?P<site>[\w\-]+)/(?P<folder>[\w\W]+)/caml',
                 ItemSharePointCamlViewSet, basename='sharepoint-caml')
+router.register(r'sharepoint/(?P<folder>[\w\W]+)/rest', SharePointRestViewSet, basename='simple-sharepoint-rest')
+router.register(r'sharepoint/(?P<folder>[\w\W]+)/caml', SharePointCamlViewSet, basename='simple-sharepoint-caml')
+router.register(r'sharepoint/(?P<folder>[\w\W]+)/files', SharePointFileViewSet, basename='simple-sharepoint-files')
 
 urlpatterns = router.urls
