@@ -2,14 +2,15 @@ from django.core.cache import caches
 from django.http import Http404, HttpResponse
 from django_filters.rest_framework import DjangoFilterBackend
 from office365.runtime.client_request_exception import ClientRequestException
+from office365.sharepoint.files.file import File
 from rest_framework import viewsets
 from rest_framework.decorators import action
 from rest_framework.exceptions import ErrorDetail, PermissionDenied
 from rest_framework.filters import OrderingFilter, SearchFilter
 
+from unicef_sharepoint import config
 from unicef_sharepoint.client import SharePointClient, SharePointClientException
 from unicef_sharepoint.filters import SharePointLibraryFilter
-from unicef_sharepoint.lib import File
 from unicef_sharepoint.models import SharePointLibrary, SharePointSite, SharePointTenant
 from unicef_sharepoint.serializers import (
     SharePointFileSerializer,
@@ -17,6 +18,7 @@ from unicef_sharepoint.serializers import (
     SharePointLibrarySerializer,
     SharePointSiteSerializer,
     SharePointTenantSerializer,
+    SimpleSharePointItemSerializer,
 )
 from unicef_sharepoint.utils import get_cache_key
 
@@ -27,10 +29,35 @@ class AbstractSharePointViewSet(viewsets.ReadOnlyModelViewSet):
     serializer_class = None
     filter_backends = (SearchFilter, DjangoFilterBackend, OrderingFilter)
 
+    def get_serializer_context(self):
+        ctx = super().get_serializer_context()
+        ctx.update({
+            'tenant': self.tenant,
+            'site': self.site,
+            'folder': self.folder
+        })
+        return ctx
+
+    def handle_exception(self, exc):
+        response = super().handle_exception(exc)
+        if isinstance(exc, Http404):
+            response.data['detail'] = ErrorDetail('No document found using selected filters', 'not_found')
+        return response
+
+    def get_cache_key(self, **kwargs):
+        key = get_cache_key([self.tenant, self.site, self.folder], **kwargs)
+        return key
+
+
+class UrlBasedSharePointViewSet(AbstractSharePointViewSet):
+
     def get_library(self):
         return SharePointLibrary.objects.get(
             site__tenant__url__contains=self.tenant, name=self.folder, site__name=self.site)
 
+    def is_public(self):
+        return self.get_library().public
+
     @property
     def client(self):
         key = self.get_cache_key(**{'client': 'client'})
@@ -53,21 +80,6 @@ class AbstractSharePointViewSet(viewsets.ReadOnlyModelViewSet):
 
         return client
 
-    def get_serializer_context(self):
-        ctx = super().get_serializer_context()
-        ctx.update({
-            'tenant': self.tenant,
-            'site': self.site,
-            'folder': self.folder
-        })
-        return ctx
-
-    def handle_exception(self, exc):
-        response = super().handle_exception(exc)
-        if isinstance(exc, Http404):
-            response.data['detail'] = ErrorDetail('No document found using selected filters', 'not_found')
-        return response
-
     @property
     def tenant(self):
         return self.kwargs.get('tenant')
@@ -80,28 +92,49 @@ class AbstractSharePointViewSet(viewsets.ReadOnlyModelViewSet):
     def folder(self):
         return self.kwargs.get('folder')
 
-    def get_cache_key(self, **kwargs):
-        key = get_cache_key([self.tenant, self.site, self.folder], **kwargs)
-        return key
+
+class SettingsBasedSharePointViewSet(AbstractSharePointViewSet):
+
+    def is_public(self):
+        return SharePointLibrary.objects.filter(name=self.folder, public=True)
+
+    @property
+    def tenant(self):
+        return config.SHAREPOINT_TENANT
+
+    @property
+    def site(self):
+        return config.SHAREPOINT_SITE
+
+    @property
+    def folder(self):
+        return self.kwargs.get('folder')
+
+    @property
+    def site_type(self):
+        return config.SHAREPOINT_SITE_TYPE
+
+    @property
+    def client(self):
+        key = self.get_cache_key(**{'client': 'client'})
+        client = cache.get(key)
+        if client is None:
+            dl_info = {
+                'url': f'{self.tenant}/{self.site_type}/{self.site}',
+                'relative_url': f'{self.site_type}/{self.site}',
+                'folder': self.folder
+            }
+            try:
+                client = SharePointClient(**dl_info)
+                cache.set(key, client)
+            except SharePointClientException:
+                raise PermissionDenied
+
+        return client
 
 
-class ItemSharePointViewSet(AbstractSharePointViewSet):
-    serializer_class = SharePointItemSerializer
+class CamlQuerySetMixin:
 
-    def get_queryset(self):
-        kwargs = self.request.query_params.dict()
-        try:
-            key = self.get_cache_key(**kwargs)
-            response = cache.get(key)
-            if response is None:
-                response = self.client.read_items(filters=kwargs)
-                cache.set(key, response)
-            return response
-        except ClientRequestException:
-            raise Http404
-
-
-class ItemSharePointCamlViewSet(ItemSharePointViewSet):
     def get_queryset(self):
         kwargs = self.request.query_params.dict()
         cache_dict = kwargs.copy()
@@ -117,7 +150,38 @@ class ItemSharePointCamlViewSet(ItemSharePointViewSet):
             raise Http404
 
 
-class FileSharePointViewSet(AbstractSharePointViewSet):
+class RestQuerySetMixin:
+
+    def get_queryset(self):
+        kwargs = self.request.query_params.dict()
+        try:
+            key = self.get_cache_key(**kwargs)
+            response = cache.get(key)
+            if response is None:
+                response = self.client.read_items(filters=kwargs)
+                cache.set(key, response)
+            return response
+        except ClientRequestException:
+            raise Http404
+
+
+class SharePointRestViewSet(RestQuerySetMixin, SettingsBasedSharePointViewSet):
+    serializer_class = SimpleSharePointItemSerializer
+
+
+class SharePointCamlViewSet(CamlQuerySetMixin, SettingsBasedSharePointViewSet):
+    serializer_class = SimpleSharePointItemSerializer
+
+
+class ItemSharePointViewSet(RestQuerySetMixin, UrlBasedSharePointViewSet):
+    serializer_class = SharePointItemSerializer
+
+
+class ItemSharePointCamlViewSet(CamlQuerySetMixin, UrlBasedSharePointViewSet):
+    serializer_class = SharePointItemSerializer
+
+
+class BaseFileSharePointViewSet(SettingsBasedSharePointViewSet):
     serializer_class = SharePointFileSerializer
     lookup_field = 'filename'
     lookup_value_regex = '[^/]+'
@@ -152,6 +216,14 @@ class FileSharePointViewSet(AbstractSharePointViewSet):
         return django_response
 
 
+class FileSharePointViewSet(BaseFileSharePointViewSet, UrlBasedSharePointViewSet):
+    pass
+
+
+class SharePointFileViewSet(BaseFileSharePointViewSet, SettingsBasedSharePointViewSet):
+    pass
+
+
 class SharePointTenantViewSet(viewsets.ReadOnlyModelViewSet):
     filter_backends = (SearchFilter, DjangoFilterBackend, OrderingFilter)
     queryset = SharePointTenant.objects.all()
